# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mkdocs_multirepo_plugin']

package_data = \
{'': ['*'], 'mkdocs_multirepo_plugin': ['scripts/*']}

install_requires = \
['asyncio']

extras_require = \
{':python_version >= "2.7" and python_version < "2.8" or python_full_version >= "3.6.0"': ['python-slugify'],
 ':python_version >= "3.6"': ['mkdocs>=1.0.4']}

entry_points = \
{'mkdocs.plugins': ['multirepo = '
                    'mkdocs_multirepo_plugin.plugin:MultirepoPlugin']}

scripts = \
['mkdocs_multirepo_plugin/scripts/sparse_clone.sh',
 'mkdocs_multirepo_plugin/scripts/sparse_clone_old.sh',
 'mkdocs_multirepo_plugin/scripts/mv_docs_up.sh']

setup_kwargs = {
    'name': 'mkdocs-multirepo-plugin',
    'version': '0.4.12',
    'description': 'Build documentation in multiple repos into one site.',
    'long_description': '# mkdocs-multirepo-plugin\n\n[![](https://github.com/jdoiro3/mkdocs-multirepo-plugin/workflows/Tests/badge.svg)](https://github.com/jdoiro3/mkdocs-multirepo-plugin/actions)\n[![](https://github.com/jdoiro3/mkdocs-multirepo-plugin/workflows/Build%2C%20Test%20%26%20Deploy/badge.svg)](https://github.com/jdoiro3/mkdocs-multirepo-plugin/actions)\n[![PyPI](https://img.shields.io/pypi/v/mkdocs-multirepo-plugin)](https://pypi.org/project/mkdocs-multirepo-plugin/)\n[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)\n![](https://img.shields.io/badge/lifecycle-beta-509bf5.svg)\n<img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/mkdocs-multirepo-plugin?style=plastic">\n\nBuild documentation in multiple repos into one site.\n\nIf you like this plugin and want me to continue maintaining it in my free time, please [buy me a 🍺](https://www.buymeacoffee.com/jdoiro)!\n\n## Features\n\n- **Distributed Documentation**: Keep docs close to the code but *findable* on one site.\n- **Seperates Concerns**: Separate documentation from other files that go into building your mkdocs site (e.g., theme overrides).\n- **Fast**: Documentation is imported asynchronously, using [asyncio](https://docs.python.org/3/library/asyncio.html).\n- **Simple**: All configuration is done within the `plugins` or `nav` sections of your *mkdocs.yml* file.\n- **Use in Production**: The plugin can be used in a CI/CD pipeline.\n\n## OS Support\n\n![Mac OS](https://img.shields.io/badge/mac%20os-000000?style=for-the-badge&logo=macos&logoColor=F0F0F0)\n![Linux](https://img.shields.io/badge/Linux-FCC624?style=for-the-badge&logo=linux&logoColor=black)\n![Ubuntu](https://img.shields.io/badge/Ubuntu-E95420?style=for-the-badge&logo=ubuntu&logoColor=white)\n![Windows](https://img.shields.io/badge/Windows-0078D6?style=for-the-badge&logo=windows&logoColor=white)\n\n## Dependencies\n\n![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)\n![Git](https://img.shields.io/badge/git-%23F05033.svg?style=for-the-badge&logo=git&logoColor=white) \n\n> Newer versions of Git preferred.\n\n## Setup\n\nInstall plugin using pip:\n\n```\npip install mkdocs-multirepo-plugin\n```\n\nNext, add the plugin to your `mkdocs.yml`\n\n```yaml\nplugins:\n  - multirepo\n```\n\nThe plugin introduces the *!import* statement in your config\'s *nav* section. You can now use the import statement to add a documentation section, where the docs are pulled from the source repo.\n\n<details><summary><b>!import Statement Sections</b></summary>\n  \n  - **{url}**: Only *required* part of *!import* statement (e.g., `https://github.com/{user}/{repo name}`).\n  - **branch={branch}**: Tells *multirepo* what branch to use. Defaults to *master* if not supplied.\n  - **docs_dir={path}**: The path to the *docs* directory for the section. Defaults to *docs/\\** (a glob) if not supplied.\n  - **multi_docs={True | False}**: If set to *True*, all *docs* directories will be imported (more info [here](#α-multiple-docs-directories-in-imported-repo-alpha)).\n  - **config={filename}.yml**: Tells *multirepo* the name of the config file, containing configuration for the plugin. The default value is also `mkdocs.yml`. This config file can live within the docs directory *or* in the parent directory.\n  - **extra_imports=["{filename | path | glob}"]**: Use this if you want to import additional directories or files along with the docs.\n\n</details>\n\n```yaml\nnav:\n  - Home: \'index.md\'\n  - MicroService: \'!import {url}?branch={branch}&docs_dir={path}&multi_docs={True | False}&config={filename}.yml\'\n```\n\n*MicroService mkdocs.yml (located within the docs directory or the parent directory)*\n```yaml\nedit_uri: /blob/master/\n\nnav:\n  - Home: index.md\n```\n\n> Things to Note:\n>\n> - If using *!import* in the *nav*, the imported repo must have a *mkdocs.yml* (or another filename with a *?config={filename}.yml*) file with a *nav* section located in either the *docs* directory or the root directory.\n> - *nav* takes precedence over *repos* (see below).\n> - *{path}* can also be a [glob](https://en.wikipedia.org/wiki/Glob_(programming)) (e.g., `docs/*`).\n\n\nIf you\'d prefer *MkDocs* to build the site nav based on the directory structure, you can define your other repos within the *plugins* section.\n\n> Note:\n> Cleanup should be set to `false` when developing (i.e., when calling `mkdocs serve`). This will prevent importing repos multiple times with livereload.\n\n```yaml\nplugins:\n  - search\n  - multirepo:\n      # (optional) tells multirepo to cleanup the temporary directory after site is built.\n      cleanup: true\n      repos:\n        - section: Backstage\n          # you can define the edit uri path\n          import_url: \'https://github.com/backstage/backstage?edit_uri=/blob/master/\'\n        - section: Monorepo\n          import_url: \'https://github.com/backstage/mkdocs-monorepo-plugin?edit_uri=/blob/master/\'\n        - section: \'Techdocs-cli\'\n          # note that the branch is still specified in the url\n          import_url: \'https://github.com/backstage/techdocs-cli?branch=main&edit_uri=/blob/main/\'\n        - section: FastAPI\n          import_url: \'https://github.com/tiangolo/fastapi?docs_dir=docs/en/docs/*\'\n        - section: Monorepo Multi Docs\n          import_url: https://github.com/backstage/mkdocs-monorepo-plugin?multi_docs=True&docs_dir=sample-docs/*\n        - section: \'Django REST\'\n          section_path: python # Put this under the python menu entry\n          import_url: \'https://github.com/encode/django-rest-framework\'\n        - section: \'Cookiecutter Pypackage\'\n          section_path: python # Put this under the python menu entry\n          import_url: \'https://github.com/zillionare/cookiecutter-pypackage\'\n        - section: \'Pydantic\'\n          section_path: python # Put this under the python menu entry\n          import_url: \'https://github.com/samuelcolvin/pydantic?branch=main\'\n```\n\nOnce you\'re done configuring, run either `mkdocs serve` or `mkdocs build`. This will `import` the docs into a temporary directory and build the site.\n\n![mkdocs-multirepo-plugin-demo](https://user-images.githubusercontent.com/57968347/183310333-07576062-d4e0-47d1-ac2c-9b682fea8b4e.gif)\n\n## Additional Features\n\n### α Multiple Docs Directories in Imported Repo (Alpha)\n\nIf an imported repo is a monorepo (i.e., has multiple *docs* directories), *multirepo* automatically includes them in the site when `multi_docs` is set to `True`.\n\nSuppose *Microservice\'s* directory structure is this.\n\n```\n├───mkdocs.yml (required if nav section is defined)\n├───README.md\n├───project1\n│   └───src\n│   └───docs\n│       └───assets\n|         index.md\n|         technical.md\n├───project2\n│   └───src\n│   └───docs\n│         index.md\n```\n\nBy default, this directory turns into this.\n\n```\n├───mkdocs.yml (required if nav section is defined)\n├───README.md\n├───project1\n│   └───assets\n|     index.md\n|     technical.md\n├───project2\n│     index.md\n```\n\n> Note: \n> - If using the nav *!import* statement, make sure the nav paths reflect the new directory structure, which doesn\'t include *docs* directories.\n> - *edit_urls* will still map to underlying markdown file based on the actual directory structure in the remote\'s repository.\n\n\n### Use in CI/CD\n\nIf you want to use the plugin within Azure Pipelines or Github Actions, you\'ll need to define an access token.\n\n#### Azure Pipelines\n\nYou\'ll need to define an `AccessToken` environment variable for the `mkdocs build` step. The access token should have access to `clone` all repos.\n\n#### Github Actions\n\nYou\'ll need to define an `GithubAccessToken` environment variable for the `mkdocs build` step. The access token should have access to `clone` all repos. This can be a personal access token or one from a GitHub App.\n\n#### Azure Pipeline Step Example\n\n```yaml\n- script: |\n    source ./env/bin/activate\n    mkdocs build\n  env:\n    AccessToken: $(System.AccessToken)\n  displayName: \'Build MkDocs Site\'\n```\n\n### β Development in Imported Repos (Beta)\n\nFor `mkdocs serve` to work properly in an imported repo (a repo that is imported in the parent site), *you will need to add the multirepo plugin within the imported repo as well as the parent repo*, including the following configuration.\n\n> Notes:\n> - You will also need to have `plugins` and `packages` the parent repo uses installed within your local `venv`.\n> - See documentation on the [set](https://git-scm.com/docs/git-sparse-checkout#Documentation/git-sparse-checkout.txt-emsetem) git command for `sparse-checkout` if you are confused with what `dirs` can contain.\n\n```yml\nplugins:\n  multirepo:\n    imported_repo: true\n    url: https://github.com/squidfunk/mkdocs-material\n    section_name: Backstage\n    # directories and files needed for building the site\n    # any path in docs will be included. For example, index.md is the\n    # homepage of the parent site\n    dirs: ["material/*", "mkdocs.yml", "docs/index.md"]\n    custom_dir: material\n    yml_file: mkdocs.yml # this can also be a relative path\n    branch: master\n```\n\nWriters can now run `mkdocs serve` within their local repo, using the main site\'s configuration, custom theming and features. This means all development is distributed, without technical writers having to switch repos.\n\n> Backstage with Material theme\n\n![site image](assets/backstage-material-theme.png)\n\n## Examples\n\n- [Multirepo with Mcdocstrings](./examples/mcdocstrings)\n\n## Contributing\n\nYou\'ll need to install [Poetry](https://python-poetry.org) and Git to contribute and run tests locally.\n\n### Setup\n\n> Assumes you have `poetry` installed and in your path\n\n```> poetry install```\n```> poetry shell```\n\n### Running Tests\n\nTests were modeled off of [mkdocs-monorepo-plugin](https://github.com/backstage/mkdocs-monorepo-plugin/blob/master/docs/CONTRIBUTING.md). To run the test suite you\'ll need:\n\n- Python\n- Git\n- Docker\n- MkDocs\n\n### Integration Testing\n\nThe command below will use Docker to run our test suites in numerous Python versions. It may take some time on first run, but should be very fast afterwards. When you\'re done, feel free to run `docker prune` to clear them from your local cache. We use the `slim` versions of the public `python` images from [Docker Hub](https://hub.docker.com).\n```\n$ ./__tests__/test.sh\n```\nFor faster tests, you can opt to run in Python 3.7 rather than all supported Python versions:\n```\n$ PYTHON_37_ONLY=1 ./__tests__/test.sh\n```\n\n### Unit Testing\n\n```\n$ python[3] -m unittest tests.unittests\n```\n\n',
    'author': 'jdoiro3',
    'author_email': 'josephdoiron1234@yahoo.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://pypi.org/project/mkdocs-multirepo-plugin/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'scripts': scripts,
}


setup(**setup_kwargs)
